@@ -203,6 +203,12 @@ impl Atom {
     }
 }
 
+impl Default for Atom {
+    fn default() -> Self {
+        atom!("")
+    }
+}
+
 impl PartialEq<str> for Atom {
     fn eq(&self, other: &str) -> bool {
         &self[..] == other
@@ -215,6 +221,12 @@ impl PartialEq<Atom> for str {
     }
 }
 
+impl PartialEq<String> for Atom {
+    fn eq(&self, other: &String) -> bool {
+        &self[..] == &other[..]
+    }
+}
+
 impl<'a> From<Cow<'a, str>> for Atom {
     #[inline]
     fn from(string_to_add: Cow<'a, str>) -> Atom {
